library ieee;
use ieee.std_logic_1164.all;
use ieee.std_logic_arith.all;
use ieee.std_logic_unsigned.all;
use ieee.numeric_std.all;

-- transcodeur specifique pour reveil : binaire 4 bits vers information logique sur 7 bits
--  (indiquant si le segment A, B... G est allume ou non)
--  0 à 9 : dessin des chiffres
--	 10 : dessin du A de alarme
--	 11 : dessin du L de alarme
--	 12 à 14 : libre 
--  15 : tous les segments éteints pour un effet de clignotement éventuel
--  entrée hl : pour gérer les led en anode commune ou cathode commune


entity transco_reveil is port (
	e : in std_logic_vector(3 downto 0);	-- valeur en entree a afficher
	hl : in std_logic;		-- gestion anode commune ou cathode commune 
	s : out std_logic_vector(6 downto 0) 	--	gestion des segments
	);
end transco_reveil;

architecture behavior of transco_reveil is
signal seg : std_logic_vector(6 downto 0);
begin

		with e select
-- 						 gfedcba	 ( pilotés actif a l'état haut par défaut )
				seg   <= "0111111" when "0000", --0
							"0000110" when "0001",	--1
							"1011011" when "0010", --2
							"1001111" when "0011",	--3
							"1100110" when "0100",--4
							"1101101" when "0101",--5
							"1111101" when "0110",--6
							"0000111" when "0111",--7
							"1111111" when "1000",--8
							"1101111" when "1001",--9
							"1110111" when "1010",--A
							"0111000" when "1011",--L
							"0000000" when "1100",-- libre tout éteint pour l'instant
							"0000000" when "1101",-- libre tout éteint pour l'instant
							"0000000" when "1110",-- libre tout éteint pour l'instant
							"0000000" when "1111",-- tout éteint
							"1000000" when others;	-- - quand il y a erreur

	process(hl,seg) begin
		if hl='1' then 
			s <= seg;
		else
			s <= not seg;
		end if;
	end process;
		
end behavior;